@@ -1,7 +1,7 @@
 """
 Type annotations for sagemaker-a2i-runtime service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/type_defs/)
 
 Usage::
 
@@ -33,6 +33,7 @@ __all__ = (
     "HumanLoopInputTypeDef",
     "HumanLoopOutputTypeDef",
     "HumanLoopSummaryTypeDef",
+    "ListHumanLoopsRequestListHumanLoopsPaginateTypeDef",
     "ListHumanLoopsRequestRequestTypeDef",
     "ListHumanLoopsResponseTypeDef",
     "PaginatorConfigTypeDef",
@@ -103,6 +104,17 @@ HumanLoopSummaryTypeDef = TypedDict(
     },
 )
 
+ListHumanLoopsRequestListHumanLoopsPaginateTypeDef = TypedDict(
+    "ListHumanLoopsRequestListHumanLoopsPaginateTypeDef",
+    {
+        "FlowDefinitionArn": str,
+        "CreationTimeAfter": NotRequired[Union[datetime, str]],
+        "CreationTimeBefore": NotRequired[Union[datetime, str]],
+        "SortOrder": NotRequired[SortOrderType],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListHumanLoopsRequestRequestTypeDef = TypedDict(
     "ListHumanLoopsRequestRequestTypeDef",
     {
